diff options
| author | Rosen Penev <rosenp@gmail.com> | 2020-08-14 17:58:19 -0700 |
|---|---|---|
| committer | Rosen Penev <rosenp@gmail.com> | 2020-08-14 18:07:28 -0700 |
| commit | 9fc278548b45f57468fa83c1b8912fbd6a1ae45f (patch) | |
| tree | 580361613c18a9c28f3b14d1c286d29072747524 /lang/python/python-simplejson | |
| parent | d34430f02f33765770e4fc748094a0a047c73265 (diff) | |
mpg123: update to 1.26.3
Switched to CMake. CMake compiles faster.
Added libsyn123 library as it's needed since version 1.26.
Before:
time make package/mpg123/compile -j 12
Executed in 16.05 secs fish external
usr time 26.65 secs 0.00 micros 26.65 secs
sys time 4.82 secs 833.00 micros 4.81 secs
After:
time make package/mpg123/compile -j 12
Executed in 12.12 secs fish external
usr time 19.35 secs 0.00 micros 19.35 secs
sys time 3.22 secs 752.00 micros 3.22 secs
Signed-off-by: Rosen Penev <rosenp@gmail.com>
Diffstat (limited to 'lang/python/python-simplejson')
0 files changed, 0 insertions, 0 deletions
